=======
Credits
=======

Original Snippet
----------------

This is originally based on a snippet by Chris Beaven (https://github.com/smileychris).
(It has been altered quite a bit. Don't expect the same behavior!)

Development Lead
----------------

* Audrey Roy Greenfeld <audreyr@gmail.com>

Contributors
------------

None yet. Why not be the first?